@@ -1,9 +1,7 @@
 package Vim::X;
-BEGIN {
-  $Vim::X::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Candy for Perl programming in Vim
-$Vim::X::VERSION = '1.2.0';
+$Vim::X::VERSION = '1.3.0';
 use strict;
 use warnings;
 
@@ -247,7 +245,7 @@ Vim::X - Candy for Perl programming in Vim
 
 =head1 VERSION
 
-version 1.2.0
+version 1.3.0
 
 =head1 SYNOPSIS
 
