@@ -1,9 +1,7 @@
 package Vim::X::Buffer;
-BEGIN {
-  $Vim::X::Buffer::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: A buffer in Vim
-$Vim::X::Buffer::VERSION = '1.2.0';
+$Vim::X::Buffer::VERSION = '1.3.0';
 use Moo;
 
 has "index" => (
@@ -96,7 +94,7 @@ Vim::X::Buffer - A buffer in Vim
 
 =head1 VERSION
 
-version 1.2.0
+version 1.3.0
 
 =head1 FUNCTIONS
 
