@@ -1,9 +1,7 @@
 package Vim::X::Cursor;
-BEGIN {
-  $Vim::X::Cursor::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: A window cursor in Vim
-$Vim::X::Cursor::VERSION = '1.2.0';
+$Vim::X::Cursor::VERSION = '1.3.0';
 use strict;
 use warnings;
 
@@ -18,8 +16,20 @@ has window => (
     required => 1,
 );
 
-has line => ( is => 'ro', required => 1 );
-has col  => ( is => 'ro', required => 1 );
+has line => ( is => 'rw', required => 1 );
+has col  => ( is => 'rw', required => 1 );
+
+before line => sub {
+    return unless @_ == 2;
+    my( $cursor, $line ) = @_;
+    $cursor->window->_window->Cursor( $line, $cursor->col );
+};
+
+before col => sub {
+    return unless @_ == 2;
+    my( $cursor, $col ) = @_;
+    $cursor->window->_window->Cursor( $cursor->line, $col );
+};
 
 sub append {
     my( $self, $stuff ) = @_;
@@ -44,7 +54,7 @@ Vim::X::Cursor - A window cursor in Vim
 
 =head1 VERSION
 
-version 1.2.0
+version 1.3.0
 
 =head1 FUNCTIONS
 
