@@ -1,9 +1,7 @@
 package Vim::X::Line;
-BEGIN {
-  $Vim::X::Line::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: A line in a Vim buffer
-$Vim::X::Line::VERSION = '1.2.0';
+$Vim::X::Line::VERSION = '1.3.0';
 use Moo;
 
 
@@ -126,7 +124,7 @@ Vim::X::Line - A line in a Vim buffer
 
 =head1 VERSION
 
-version 1.2.0
+version 1.3.0
 
 =head1 METHODS
 
