@@ -1,8 +1,6 @@
 package Vim::X::Plugin::ResolveConflict;
-BEGIN {
-  $Vim::X::Plugin::ResolveConflict::AUTHORITY = 'cpan:YANICK';
-}
-$Vim::X::Plugin::ResolveConflict::VERSION = '1.2.0';
+our $AUTHORITY = 'cpan:YANICK';
+$Vim::X::Plugin::ResolveConflict::VERSION = '1.3.0';
 use strict;
 use warnings;
 
@@ -47,7 +45,7 @@ Vim::X::Plugin::ResolveConflict
 
 =head1 VERSION
 
-version 1.2.0
+version 1.3.0
 
 =head1 AUTHOR
 
