@@ -1,9 +1,7 @@
 package Vim::X::Range;
-BEGIN {
-  $Vim::X::Range::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: A range of lines in a Vim buffer
-$Vim::X::Range::VERSION = '1.2.0';
+$Vim::X::Range::VERSION = '1.3.0';
 use Moo;
 
 use overload 
@@ -107,7 +105,7 @@ Vim::X::Range - A range of lines in a Vim buffer
 
 =head1 VERSION
 
-version 1.2.0
+version 1.3.0
 
 =head1 DESCRIPTION
 
