@@ -1,9 +1,7 @@
 package Vim::X::Window;
-BEGIN {
-  $Vim::X::Window::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: A window in Vim
-$Vim::X::Window::VERSION = '1.2.0';
+$Vim::X::Window::VERSION = '1.3.0';
 use strict;
 use warnings;
 
@@ -52,7 +50,7 @@ Vim::X::Window - A window in Vim
 
 =head1 VERSION
 
-version 1.2.0
+version 1.3.0
 
 =head1 FUNCTIONS
 
